@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# $Id: disk_usage.py 1143 2011-10-05 19:11:59Z g.rodola $
+# $Id: disk_usage.py 1236 2011-12-13 19:00:35Z g.rodola $
 #
 # Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
 # Use of this source code is governed by a BSD-style license that can be
@@ -13,10 +13,17 @@ List all mounted disk partitions a-la "df -h" command.
 import sys
 import psutil
 
-def convert_bytes(n):
-    if n == 0:
-        return "0B"
-    symbols = ('k', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
+def print_(s):
+    # python 2/3 compatibility layer
+    sys.stdout.write(s + '\n')
+    sys.stdout.flush()
+
+def bytes2human(n):
+    # >>> bytes2human(10000)
+    # '9.8K'
+    # >>> bytes2human(100001221)
+    # '95.4M'
+    symbols = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
     prefix = {}
     for i, s in enumerate(symbols):
         prefix[s] = 1 << (i+1)*10
@@ -24,20 +31,21 @@ def convert_bytes(n):
         if n >= prefix[s]:
             value = float(n) / prefix[s]
             return '%.1f%s' % (value, s)
+    return "%sB" % n
 
 
 def main():
     templ = "%-17s %8s %8s %8s %5s%% %9s  %s"
-    print templ % ("Device", "Total", "Used", "Free", "Use ", "Type", "Mount")
+    print_(templ % ("Device", "Total", "Used", "Free", "Use ", "Type", "Mount"))
     for part in psutil.disk_partitions(all=False):
         usage = psutil.disk_usage(part.mountpoint)
-        print templ % (part.device,
-                       convert_bytes(usage.total),
-                       convert_bytes(usage.used),
-                       convert_bytes(usage.free),
-                       int(usage.percent),
-                       part.fstype,
-                       part.mountpoint)
+        print_(templ % (part.device,
+                        bytes2human(usage.total),
+                        bytes2human(usage.used),
+                        bytes2human(usage.free),
+                        int(usage.percent),
+                        part.fstype,
+                        part.mountpoint))
 
 if __name__ == '__main__':
     sys.exit(main())
