@@ -1,5 +1,5 @@
 /*
- * $Id: _psutil_bsd.c 1206 2011-10-26 21:13:51Z g.rodola $
+ * $Id: _psutil_bsd.c 1237 2011-12-14 17:56:08Z g.rodola $
  *
  * Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
  * Use of this source code is governed by a BSD-style license that can be
@@ -20,6 +20,7 @@
 #include <sys/user.h>
 #include <sys/proc.h>
 #include <sys/socket.h>
+#include <fcntl.h>
 #include <devstat.h>      /* get io counters */
 #include <sys/vmmeter.h>  /* needed for vmtotal struct */
 #include <libutil.h>      /* process open files */
@@ -654,7 +655,7 @@ get_system_cpu_times(PyObject* self, PyObject* args)
  * These functions are available on FreeBSD 8 only.
  * In the upper python layer we do various tricks to avoid crashing
  * and/or to provide alternatives where possible.
- */ 
+ */
 
 
 #if defined(__FreeBSD_version) && __FreeBSD_version >= 800000
@@ -1125,4 +1126,3 @@ void init_psutil_bsd(void)
     return module;
 #endif
 }
-
