@@ -1,5 +1,5 @@
 /*
- * $Id: _psutil_linux.c 1166 2011-10-17 22:18:07Z g.rodola $
+ * $Id: _psutil_linux.c 1237 2011-12-14 17:56:08Z g.rodola $
  *
  * Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
  * Use of this source code is governed by a BSD-style license that can be
@@ -12,6 +12,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <mntent.h>
+#include <utmp.h>
 #include <sys/syscall.h>
 #include <sys/sysinfo.h>
 #include <linux/unistd.h>
@@ -140,7 +141,10 @@ get_physmem(PyObject* self, PyObject* args)
     if (sysinfo(&info) != 0) {
         return PyErr_SetFromErrno(PyExc_OSError);
     }
-    return Py_BuildValue("(lll)", info.totalram, info.freeram, info.bufferram);
+    return Py_BuildValue("(KKK)",
+        info.totalram *(unsigned long long)info.mem_unit,
+        info.freeram * (unsigned long long)info.mem_unit,
+        info.bufferram * (unsigned long long)info.mem_unit);
 }
 
 
@@ -225,4 +229,3 @@ void init_psutil_linux(void)
     return module;
 #endif
 }
-
