@@ -1,5 +1,5 @@
 /*
- * $Id: _psutil_mswindows.c 1202 2011-10-24 19:00:50Z g.rodola $
+ * $Id: _psutil_mswindows.c 1238 2011-12-14 19:19:13Z g.rodola $
  *
  * Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
  * Use of this source code is governed by a BSD-style license that can be
@@ -481,7 +481,9 @@ get_memory_info(PyObject* self, PyObject* args)
         CloseHandle(hProcess);
         return PyErr_SetFromWindowsErr(0);
     }
-    
+
+    CloseHandle(hProcess);
+
 // py 2.4
 #if (PY_MAJOR_VERSION == 2) && (PY_MINOR_VERSION <= 4)
     return Py_BuildValue("(II)", (unsigned int)counters.WorkingSetSize,
@@ -787,6 +789,7 @@ suspend_resume_process(DWORD pid, int suspend)
         }
     } while (Thread32Next(hThreadSnap, &te32));
 
+    CloseHandle(hThreadSnap);
     return TRUE;
 }
 
@@ -1218,6 +1221,11 @@ typedef struct _MIB_UDP6TABLE_OWNER_PID
 } MIB_UDP6TABLE_OWNER_PID, *PMIB_UDP6TABLE_OWNER_PID;
 
 
+#define ConnDecrefPyObjs() Py_DECREF(_AF_INET); \
+                           Py_DECREF(_AF_INET6);\
+                           Py_DECREF(_SOCK_STREAM);\
+                           Py_DECREF(_SOCK_DGRAM);
+
 /*
  * Return a list of network connections opened by a process
  */
@@ -1231,6 +1239,12 @@ get_process_connections(PyObject* self, PyObject* args)
     PyObject* connectionTuple;
     PyObject *af_filter = NULL;
     PyObject *type_filter = NULL;
+
+    PyObject *_AF_INET = PyLong_FromLong((long)AF_INET);
+    PyObject *_AF_INET6 = PyLong_FromLong((long)AF_INET6);
+    PyObject *_SOCK_STREAM = PyLong_FromLong((long)SOCK_STREAM);
+    PyObject *_SOCK_DGRAM = PyLong_FromLong((long)SOCK_DGRAM);
+
     typedef PSTR (NTAPI *_RtlIpv4AddressToStringA)(struct in_addr *,
                                                    PSTR /* __out_ecount(16) */);
     _RtlIpv4AddressToStringA rtlIpv4AddressToStringA;
@@ -1256,15 +1270,18 @@ get_process_connections(PyObject* self, PyObject* args)
     PyObject* addressTupleRemote;
 
     if (! PyArg_ParseTuple(args, "lOO", &pid, &af_filter, &type_filter)) {
+        ConnDecrefPyObjs();
         return NULL;
     }
 
     if (!PySequence_Check(af_filter) || !PySequence_Check(type_filter)) {
+        ConnDecrefPyObjs();
         PyErr_SetString(PyExc_TypeError, "arg 2 or 3 is not a sequence");
         return NULL;
     }
 
     if (pid_is_running(pid) == 0) {
+        ConnDecrefPyObjs();
         return NoSuchProcess();
     }
 
@@ -1290,6 +1307,7 @@ get_process_connections(PyObject* self, PyObject* args)
     if ((getExtendedTcpTable == NULL) || (getExtendedUdpTable == NULL)) {
         PyErr_SetString(PyExc_NotImplementedError,
                         "feature not supported on this Windows version");
+        ConnDecrefPyObjs();
         return NULL;
     }
 
@@ -1297,8 +1315,8 @@ get_process_connections(PyObject* self, PyObject* args)
 
     /* TCP IPv4 */
 
-    if ((PySequence_Contains(af_filter, PyLong_FromLong((long)AF_INET)) == 1) &&
-        (PySequence_Contains(type_filter, PyLong_FromLong((long)SOCK_STREAM)) == 1))
+    if ((PySequence_Contains(af_filter, _AF_INET) == 1) &&
+        (PySequence_Contains(type_filter, _SOCK_STREAM) == 1))
     {
         tableSize = 0;
         getExtendedTcpTable(NULL, &tableSize, FALSE, AF_INET,
@@ -1359,6 +1377,7 @@ get_process_connections(PyObject* self, PyObject* args)
                     state_to_string(tcp4Table->table[i].dwState)
                     );
                 PyList_Append(connectionsList, connectionTuple);
+                Py_DECREF(connectionTuple);
             }
         }
 
@@ -1367,8 +1386,8 @@ get_process_connections(PyObject* self, PyObject* args)
 
     /* TCP IPv6 */
 
-    if ((PySequence_Contains(af_filter, PyLong_FromLong((long)AF_INET6)) == 1) &&
-        (PySequence_Contains(type_filter, PyLong_FromLong((long)SOCK_STREAM)) == 1))
+    if ((PySequence_Contains(af_filter, _AF_INET6) == 1) &&
+        (PySequence_Contains(type_filter, _SOCK_STREAM) == 1))
     {
         tableSize = 0;
         getExtendedTcpTable(NULL, &tableSize, FALSE, AF_INET6,
@@ -1429,6 +1448,7 @@ get_process_connections(PyObject* self, PyObject* args)
                     state_to_string(tcp6Table->table[i].dwState)
                     );
                 PyList_Append(connectionsList, connectionTuple);
+                Py_DECREF(connectionTuple);
             }
         }
 
@@ -1437,8 +1457,8 @@ get_process_connections(PyObject* self, PyObject* args)
 
     /* UDP IPv4 */
 
-    if ((PySequence_Contains(af_filter, PyLong_FromLong((long)AF_INET)) == 1) &&
-        (PySequence_Contains(type_filter, PyLong_FromLong((long)SOCK_DGRAM)) == 1))
+    if ((PySequence_Contains(af_filter, _AF_INET) == 1) &&
+        (PySequence_Contains(type_filter, _SOCK_DGRAM) == 1))
     {
         tableSize = 0;
         getExtendedUdpTable(NULL, &tableSize, FALSE, AF_INET,
@@ -1481,6 +1501,7 @@ get_process_connections(PyObject* self, PyObject* args)
                     ""
                     );
                 PyList_Append(connectionsList, connectionTuple);
+                Py_DECREF(connectionTuple);
             }
         }
 
@@ -1489,8 +1510,8 @@ get_process_connections(PyObject* self, PyObject* args)
 
     /* UDP IPv6 */
 
-    if ((PySequence_Contains(af_filter, PyLong_FromLong((long)AF_INET6)) == 1) &&
-        (PySequence_Contains(type_filter, PyLong_FromLong((long)SOCK_DGRAM)) == 1))
+    if ((PySequence_Contains(af_filter, _AF_INET6) == 1) &&
+        (PySequence_Contains(type_filter, _SOCK_DGRAM) == 1))
     {
         tableSize = 0;
         getExtendedUdpTable(NULL, &tableSize, FALSE,
@@ -1533,12 +1554,14 @@ get_process_connections(PyObject* self, PyObject* args)
                     ""
                     );
                 PyList_Append(connectionsList, connectionTuple);
+                Py_DECREF(connectionTuple);
             }
         }
 
         free(table);
     }
 
+    ConnDecrefPyObjs();
     return connectionsList;
 }
 
@@ -1706,7 +1729,7 @@ get_network_io_counters(PyObject* self, PyObject* args)
     PyObject* py_nic_info = NULL;
     PyObject* py_pre_nic_name = NULL;
     PyObject* py_nic_name = NULL;
-    
+
     int attempts = 0;
     int outBufLen = 15000;
     DWORD dwRetVal = 0;
@@ -1715,22 +1738,22 @@ get_network_io_counters(PyObject* self, PyObject* args)
     ULONG family = AF_UNSPEC;
     PIP_ADAPTER_ADDRESSES pAddresses = NULL;
     PIP_ADAPTER_ADDRESSES pCurrAddresses = NULL;
- 
-    do {        
+
+    do {
         pAddresses = (IP_ADAPTER_ADDRESSES *) malloc(outBufLen);
         if (pAddresses == NULL) {
             Py_DECREF(py_retdict);
-            PyErr_SetString(PyExc_RuntimeError, 
+            PyErr_SetString(PyExc_RuntimeError,
                 "memory allocation failed for IP_ADAPTER_ADDRESSES struct.");
             return NULL;
         }
 
-        dwRetVal = GetAdaptersAddresses(family, flags, NULL, pAddresses, 
+        dwRetVal = GetAdaptersAddresses(family, flags, NULL, pAddresses,
                                         &outBufLen);
         if (dwRetVal == ERROR_BUFFER_OVERFLOW) {
             free(pAddresses);
             pAddresses = NULL;
-        } 
+        }
         else {
             break;
         }
@@ -1743,17 +1766,17 @@ get_network_io_counters(PyObject* self, PyObject* args)
         PyErr_SetString(PyExc_RuntimeError,  "GetAdaptersAddresses() failed.");
         return NULL;
     }
-    
+
     pCurrAddresses = pAddresses;
     while (pCurrAddresses) {
         pIfRow = (MIB_IFROW *) malloc(sizeof(MIB_IFROW));
-        
+
         if (pIfRow == NULL) {
             Py_DECREF(py_retdict);
             Py_XDECREF(py_pre_nic_name);
             Py_XDECREF(py_nic_name);
             Py_XDECREF(py_nic_info);
-            PyErr_SetString(PyExc_RuntimeError, 
+            PyErr_SetString(PyExc_RuntimeError,
                 "memory allocation failed for MIB_IFROW struct.");
             return NULL;
         }
@@ -1765,17 +1788,17 @@ get_network_io_counters(PyObject* self, PyObject* args)
             Py_XDECREF(py_pre_nic_name);
             Py_XDECREF(py_nic_name);
             Py_XDECREF(py_nic_info);
-            PyErr_SetString(PyExc_RuntimeError, 
+            PyErr_SetString(PyExc_RuntimeError,
                 "GetIfEntry() failed.");
             return NULL;
         }
-        
+
         py_nic_info = Py_BuildValue("(IIII)",
                                     pIfRow->dwOutOctets,
                                     pIfRow->dwInOctets,
                                     pIfRow->dwOutUcastPkts,
-                                    pIfRow->dwInUcastPkts);          
-                          
+                                    pIfRow->dwInUcastPkts);
+
         py_pre_nic_name = PyUnicode_FromWideChar(
                                 pCurrAddresses->FriendlyName,
                                 wcslen(pCurrAddresses->FriendlyName));
@@ -1816,8 +1839,11 @@ get_disk_io_counters(PyObject* self, PyObject* args)
         hDevice = CreateFile (szDevice, 0, FILE_SHARE_READ | FILE_SHARE_WRITE,
                               NULL, OPEN_EXISTING, 0, NULL);
 
-        if (hDevice == INVALID_HANDLE_VALUE)
+        if (hDevice == INVALID_HANDLE_VALUE) {
+            // what happens if we get an invalid handle on the first disk?
+            // we might end up with an empty dict incorrectly in some cases
             break;
+        }
 
         if (DeviceIoControl (hDevice, IOCTL_DISK_PERFORMANCE, NULL, 0,
             &diskPerformance, sizeof (DISK_PERFORMANCE), &dwSize, NULL)) {
