@@ -1,7 +1,12 @@
 #!/usr/bin/env python
 #
-# $Id: _posix.py 935 2011-02-22 22:19:33Z g.rodola $
+# $Id: _posix.py 1204 2011-10-24 19:19:01Z g.rodola $
 #
+# Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
+# Use of this source code is governed by a BSD-style license that can be
+# found in the LICENSE file.
+
+"""POSIX specific tests.  These are implicitly run by test_psutil.py."""
 
 import unittest
 import subprocess
@@ -12,7 +17,7 @@ import os
 import psutil
 
 from test_psutil import (get_test_subprocess, reap_children, PYTHON, LINUX, OSX,
-                         ignore_access_denied)
+                         ignore_access_denied, sh)
 
 
 def ps(cmd):
@@ -86,12 +91,9 @@ class PosixSpecificTestCase(unittest.TestCase):
         # use command + arg since "comm" keyword not supported on all platforms
         name_ps = ps("ps --no-headers -o command -p %s" %self.pid).split(' ')[0]
         # remove path if there is any, from the command
-        name_ps = os.path.basename(name_ps)
-        name_psutil = psutil.Process(self.pid).name
-        if OSX:
-            self.assertEqual(name_psutil, "Python")
-        else:
-            self.assertEqual(name_ps, name_psutil)
+        name_ps = os.path.basename(name_ps).lower()
+        name_psutil = psutil.Process(self.pid).name.lower()
+        self.assertEqual(name_ps, name_psutil)
 
     def test_process_exe(self):
         ps_pathname = ps("ps --no-headers -o command -p %s" %self.pid).split(' ')[0]
@@ -105,9 +107,8 @@ class PosixSpecificTestCase(unittest.TestCase):
             # "/usr/local/bin/python"
             # We do not want to consider this difference in accuracy
             # an error.
-            ps_extended_pathname = PYTHON + "%s.%s" % (sys.version_info.major,
-                                                       sys.version_info.minor)
-            self.assertEqual(ps_extended_pathname, psutil_pathname)
+            adjusted_ps_pathname = ps_pathname[:len(ps_pathname)]
+            self.assertEqual(ps_pathname, adjusted_ps_pathname)
 
     def test_process_cmdline(self):
         ps_cmdline = ps("ps --no-headers -o command -p %s" %self.pid)
@@ -129,19 +130,30 @@ class PosixSpecificTestCase(unittest.TestCase):
                 pids_ps.append(int(pid.strip()))
         # remove ps subprocess pid which is supposed to be dead in meantime
         pids_ps.remove(p.pid)
-        # not all systems include pid 0 in their list but psutil does so
-        # we force it
-        if 0 not in pids_ps:
-            pids_ps.append(0)
-
         pids_psutil = psutil.get_pid_list()
         pids_ps.sort()
         pids_psutil.sort()
 
+        # on OSX ps doesn't show pid 0
+        if OSX and 0 not in pids_ps:
+            pids_ps.insert(0, 0)
+
         if pids_ps != pids_psutil:
-            difference = filter(lambda x:x not in pids_ps, pids_psutil) + \
-                         filter(lambda x:x not in pids_psutil, pids_ps)
+            difference = [x for x in pids_psutil if x not in pids_ps] + \
+                         [x for x in pids_ps if x not in pids_psutil]
             self.fail("difference: " + str(difference))
+            
+    def test_nic_names(self):
+        p = subprocess.Popen("ifconfig -a", shell=1, stdout=subprocess.PIPE)
+        output = p.communicate()[0].strip()
+        if sys.version_info >= (3,):
+            output = str(output, sys.stdout.encoding)
+        for nic in psutil.network_io_counters(pernic=True).keys():
+            for line in output.split():
+                if line.startswith(nic):
+                    break
+            else:
+                self.fail("couldn't find %s nic in 'ifconfig -a' output" % nic)
 
 
 if __name__ == '__main__':
